# geodemo_fm


[![image](https://img.shields.io/pypi/v/geodemo_fm.svg)](https://pypi.python.org/pypi/geodemo_fm)

# Welcome to geodemo_fm

[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://gishub.org/geodemo_fm-colab)
[![image](https://img.shields.io/conda/vn/conda-forge/geodemo_fm.svg)](https://anaconda.org/conda-forge/geodemo_fm)
[![image](https://pepy.tech/badge/geodemo_fm)](https://pepy.tech/project/geodemo_fm)
[![image](https://github.com/giswqs/geodemo_fm/workflows/docs/badge.svg)](https://geodemo_fm.org)
[![image](https://github.com/giswqs/geodemo_fm/workflows/build/badge.svg)](https://github.com/giswqs/geodemo_fm/actions?query=workflow%3Abuild)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


**A Python package for interactive mapping with Google Earth Engine, ipyleaflet, and ipywidgets.**

**This package is used for georeferencing**


-   Free software: MIT license
-   Documentation: https://faraigit.github.io/geodemo_fm
    
## Features
 To do
 To do 2
 
 ## Credits
 


This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
